# DUMMY IMPLEMENTATION

class MyClass:

    def __init__(self):
        pass

    def some_function(self, param1, param2):
        """
        Documentation for this function...

        :param param1: info on param1
        :param param2: info on param2
        """
        pass
